"use strict";

exports.__esModule = true;
exports.useCodeMirror = useCodeMirror;

var _react = require("react");

var _basicSetup = require("@codemirror/basic-setup");

var _state = require("@codemirror/state");

var _commands = require("@codemirror/commands");

var _view = require("@codemirror/view");

var _themeOneDark = require("@codemirror/theme-one-dark");

var _light = require("./theme/light");

function useCodeMirror(props) {
  var value = props.value,
      selection = props.selection,
      onChange = props.onChange,
      _props$extensions = props.extensions,
      extensions = _props$extensions === void 0 ? [] : _props$extensions,
      _props$theme = props.theme,
      theme = _props$theme === void 0 ? 'light' : _props$theme,
      _props$height = props.height,
      height = _props$height === void 0 ? '' : _props$height,
      _props$minHeight = props.minHeight,
      minHeight = _props$minHeight === void 0 ? '' : _props$minHeight,
      _props$maxHeight = props.maxHeight,
      maxHeight = _props$maxHeight === void 0 ? '' : _props$maxHeight,
      _props$width = props.width,
      width = _props$width === void 0 ? '' : _props$width,
      _props$minWidth = props.minWidth,
      minWidth = _props$minWidth === void 0 ? '' : _props$minWidth,
      _props$maxWidth = props.maxWidth,
      maxWidth = _props$maxWidth === void 0 ? '' : _props$maxWidth;

  var _useState = (0, _react.useState)(props.container),
      container = _useState[0],
      setContainer = _useState[1];

  var _useState2 = (0, _react.useState)(),
      view = _useState2[0],
      setView = _useState2[1];

  var _useState3 = (0, _react.useState)(),
      state = _useState3[0],
      setState = _useState3[1];

  var defaultThemeOption = _view.EditorView.theme({
    "&": {
      height: height,
      minHeight: minHeight,
      maxHeight: maxHeight,
      width: width,
      minWidth: minWidth,
      maxWidth: maxWidth
    }
  });

  var updateListener = _view.EditorView.updateListener.of(function (vu) {
    if (vu.docChanged && typeof onChange === 'function') {
      var doc = vu.state.doc;

      var _value = doc.toString();

      onChange(_value, vu);
    }
  });

  var getExtensions = [_basicSetup.basicSetup, _view.keymap.of([_commands.indentWithTab]), updateListener, defaultThemeOption];
  theme === 'light' ? getExtensions.push(_light.defaultLightThemeOption) : getExtensions.push(_themeOneDark.oneDarkTheme);
  getExtensions = getExtensions.concat(extensions);
  (0, _react.useEffect)(function () {
    if (container && !state) {
      var stateCurrent = _state.EditorState.create({
        doc: value,
        selection: selection,
        extensions: getExtensions
      });

      setState(stateCurrent);

      if (!view) {
        var viewCurrent = new _view.EditorView({
          state: stateCurrent,
          parent: container
        });
        setView(viewCurrent);
      }
    } // eslint-disable-next-line react-hooks/exhaustive-deps

  }, [container, state]);
  (0, _react.useEffect)(function () {
    return function () {
      if (view) {
        view.destroy();
      }
    };
  }, [view]);
  (0, _react.useEffect)(function () {
    if (view) {
      var currentValue = view.state.doc.toString();
      view.dispatch({
        changes: {
          from: 0,
          to: currentValue.length,
          insert: value || ''
        }
      });
    }
  }, [value, view]);
  (0, _react.useEffect)(function () {
    if (view) {
      view.dispatch({
        effects: _state.StateEffect.reconfigure.of(getExtensions)
      });
    } // eslint-disable-next-line react-hooks/exhaustive-deps

  }, [theme, extensions, height, minHeight, maxHeight, width, minWidth, maxWidth]);
  return {
    state: state,
    setState: setState,
    view: view,
    setView: setView,
    container: container,
    setContainer: setContainer
  };
}
//# sourceMappingURL=useCodeMirror.js.map